fn analyze_view_suffixes(
pipeline: &mut PipelineData<'_>,
view_suffixes: &Vec<ViewSuffix>,
)Expand description
Redundancy check for an array of strings that represent view suffixes. The lexer already generates a specific token type for view suffixes, and the parser grammar expects this token type, so we already are guaranteed that the view suffixes are valid.